/* Copyright 2000 Red Hat, Inc.
 *
 * Than Ngo <than@redhat.de>
 *
 * This software may be freely redistributed under the terms of the GNU
 * public license.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include <stdlib.h>
#include <iostream>

#ifndef QTONLY
#  include <klocale.h>
#else
#  include "kde-int.h"
#endif

#include "isdncard.h"
#include "generaldata.h"


ISDNCard::ISDNCard(QWidget * parent, const char *name)
	: QWidget(parent, name)
{
  QBoxLayout *toplayout = new QVBoxLayout(this, 8);
  QBoxLayout *isdncard_layout = new QHBoxLayout(toplayout);

  isdncard = new QCheckBox(i18n("Enable ISDN &card:"), this);
  connect(isdncard, SIGNAL(toggled(bool)), SLOT(slotSetisdncard(bool)));
  QToolTip::add(isdncard, i18n("Enable or disable ISDN card"));
  isdncard_layout->addWidget(isdncard);

  isdnlist = new QComboBox(this);
  QToolTip::add(isdnlist, i18n("Choose your ISDN card from the list"));
  for (register int i = 0; ResourceData::isdntype[i] != NULL; i += ISDNTYPE_ITEMS)
    isdnlist->insertItem(i18n(ResourceData::isdntype[i]));

  connect(isdnlist, SIGNAL(activated(const QString &)),
          SLOT(slotSetResource(const QString &)));
  connect(isdnlist, SIGNAL(activated(int)), SIGNAL(somethingChanged()));
  isdncard_layout->addWidget(isdnlist, 1);

  QBoxLayout *proto_resource_layout = new QHBoxLayout(toplayout);

  // Resources
  resource_box = new QGroupBox(2, Qt::Horizontal, i18n("Resources"), this);
  proto_resource_layout->addWidget(resource_box);

  QLabel *label = new QLabel(i18n("&IRQ:"), resource_box);
  irq = new QSpinBox(1, 15, 1, resource_box);
  label->setBuddy(irq);
  QToolTip::add(irq, i18n("Set the interrupt to selected ISDN card"));
  connect(irq, SIGNAL(valueChanged(int)), SLOT(irqChange(int)));

  label = new QLabel(i18n("&MEM:"), resource_box);
  mem = new QLineEdit(resource_box);
  label->setBuddy(mem);
  QToolTip::add(mem, i18n("Set memory address to selected ISDN card"));
  connect(mem, SIGNAL(textChanged(const QString &)),
          SLOT(memChange(const QString &)));

  label = new QLabel(i18n("I&O:"), resource_box);
  io = new QLineEdit(resource_box);
  label->setBuddy(io);
  QToolTip::add(io, i18n("Set I/O port to selected ISDN card"));
  connect(io, SIGNAL(textChanged(const QString &)),
          SLOT(ioChange(const QString &)));

  label = new QLabel(i18n("IO&1:"), resource_box);
  io1 = new QLineEdit(resource_box);
  label->setBuddy(io1);
  QToolTip::add(io1, i18n("Set I/O port to selected ISDN card"));
  connect(io1, SIGNAL(textChanged(const QString &)),
          SLOT(io1Change(const QString &)));

  label = new QLabel(i18n("IO&2:"), resource_box);
  io2 = new QLineEdit(resource_box);
  label->setBuddy(io2);
  QToolTip::add(io2, i18n("Set I/O port to selected ISDN card"));
  connect(io2, SIGNAL(textChanged(const QString &)),
          SLOT(io2Change(const QString &)));

  // Protocol
  QBoxLayout *proto_layout = new QVBoxLayout(proto_resource_layout);
  f = new QVButtonGroup(i18n("D channel protocol"), this);
  connect(f, SIGNAL(clicked(int)), SLOT(slotDChannelProtoChange(int)));
  
  tr6 = new QRadioButton(i18n("1&TR6"), f);
  QToolTip::add(tr6, i18n("Set german 1TR6 protocol"));
  
  euro = new QRadioButton(i18n("&Euro ISDN (EDSS1)"), f);
  QToolTip::add(euro, i18n("Set Euro ISDN (EDSS1)"));
  euro->setChecked(true);
  
  proto_layout->addWidget(f);
  
  filldialog();
}

void ISDNCard::filldialog()
{
  for (int i = 0; i < isdnlist->count(); i++) {
    if (isdnlist->text(i) == ISDNData.resourcedata.isdncardname) {
      isdnlist->setCurrentItem(i);
      break;
    }
  }
  
  if (!ISDNData.resourcedata.irq)
    irq->setEnabled(false);
  else {
    irq->setEnabled(TRUE);
    irq->setValue(ISDNData.resourcedata.irq);
  }

  if (ISDNData.resourcedata.mem.length()) {
    mem->setEnabled(TRUE);
    mem->setText(ISDNData.resourcedata.mem);
  }
  else
    mem->setEnabled(FALSE);
  
  if (ISDNData.resourcedata.io.length()) {
    io->setEnabled(TRUE);
    io->setText(ISDNData.resourcedata.io);
  }
  else
    io->setEnabled(FALSE);

  if (ISDNData.resourcedata.io1.length()) {
    io1->setEnabled(TRUE);
    io1->setText(ISDNData.resourcedata.io1);
  }
  else
    io1->setEnabled(FALSE);

  if (ISDNData.resourcedata.io2.length()) {
    io2->setEnabled(TRUE);
    io2->setText(ISDNData.resourcedata.io2);
  }
  else
    io2->setEnabled(FALSE);

  if (ISDNData.resourcedata.protocol == EURO)
    euro->setChecked(TRUE);
  else
    tr6->setChecked(TRUE);

  isdncard->setChecked(ISDNData.resourcedata.isenabled);
  slotSetisdncard(ISDNData.resourcedata.isenabled);
}

void ISDNCard::slotSetisdncard(bool t)
{
  isdnlist->setEnabled(t);
  resource_box->setEnabled(t);
  f->setEnabled(t);
  ISDNData.resourcedata.isenabled = t;
  emit somethingChanged();
}

void ISDNCard::slotSetResource(const QString & s)
{
  int i;
  
  // isdncard name
  ISDNData.resourcedata.isdncardname = s;
  
  for (i = 0; ResourceData::isdntype[i] != NULL; i += ISDNTYPE_ITEMS) {
    if (s == ResourceData::isdntype[i])
      break;
  }

  // ISDN type
  ISDNData.resourcedata.type =
    QString(ResourceData::isdntype[i + 1]).toInt();

  // irq
  if (QString(ResourceData::isdntype[i + 2]).isEmpty()) {
    irq->setEnabled(FALSE);
    ISDNData.resourcedata.irq = 0;
  }
  else {
    ISDNData.resourcedata.irq = QString(ResourceData::isdntype[i + 2]).toInt();
    irq->setValue(QString(ResourceData::isdntype[i + 2]).toInt());
    irq->setEnabled(TRUE);
  }

  // io
  if (QString(ResourceData::isdntype[i + 3]).isEmpty()) {
    io->setEnabled(FALSE);
    ISDNData.resourcedata.io = "";
  }
  else {
    ISDNData.resourcedata.io = ResourceData::isdntype[i + 3];
    io->setText(ResourceData::isdntype[i + 3]);
    io->setEnabled(TRUE);
  }

  // io1
  if (QString(ResourceData::isdntype[i + 4]).isEmpty()) {
    ISDNData.resourcedata.io1 = "";
    io1->setEnabled(FALSE);
  }
  else {
    ISDNData.resourcedata.io1 = ResourceData::isdntype[i + 4];
    io1->setText(ResourceData::isdntype[i + 4]);
    io1->setEnabled(TRUE);
  }

  // io2
  if (QString(ResourceData::isdntype[i + 5]).isEmpty()) {
    ISDNData.resourcedata.io2 = "";
    io2->setEnabled(FALSE);
  }
  else {
    ISDNData.resourcedata.io2 = ResourceData::isdntype[i + 5];
    io2->setText(ResourceData::isdntype[i + 5]);
    io2->setEnabled(TRUE);
  }
  
  // mem
  if (QString(ResourceData::isdntype[i + 6]).isEmpty()) {
    ISDNData.resourcedata.mem = "";
    mem->setEnabled(FALSE);
  }
  else {
    ISDNData.resourcedata.mem = ResourceData::isdntype[i + 6];
    mem->setText(ResourceData::isdntype[i + 6]);
    mem->setEnabled(TRUE);
  }

  // pci_id
  ISDNData.resourcedata.pci_id = ResourceData::isdntype[i + 7];

  // firmware
  ISDNData.resourcedata.firmware = ResourceData::isdntype[i + 8];

  // module, added Aug 2002 -KK
  ISDNData.resourcedata.module = ResourceData::isdntype[i + 9];
}

void ISDNCard::irqChange(int myirq)
{
  ISDNData.resourcedata.irq = myirq;
  emit somethingChanged();
}

void ISDNCard::memChange(const QString & s)
{
  ISDNData.resourcedata.mem = s;
  emit somethingChanged();
}

void ISDNCard::ioChange(const QString & s)
{
  ISDNData.resourcedata.io = s;
  emit somethingChanged();
}

void ISDNCard::io1Change(const QString & s)
{
  ISDNData.resourcedata.io1 = s;
  emit somethingChanged();
}

void ISDNCard::io2Change(const QString & s)
{
  ISDNData.resourcedata.io2 = s;
  emit somethingChanged();
}

void ISDNCard::slotDChannelProtoChange(int proto)
{
  ISDNData.resourcedata.protocol = proto + 1;
  emit somethingChanged();
}

ISDNCard::~ISDNCard()
{
}
