/* Copyright 2000 Red Hat, Inc.
 *
 * Than Ngo <than@redhat.de>
 *
 * This software may be freely redistributed under the terms of the GNU
 * public license.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef KDE_INT_H
#define KDE_INT_H

#include "config.h"

#ifdef QTONLY
#include <libintl.h>
#define i18n(x) gettext(x)
#define extraMotifWidth 0
#define extraMotifHeight 0
#define minButtonWidth 50

#include <qpixmap.h>
#include <qstring.h>
#include <qframe.h>
#include <qwidget.h>
#include <qpushbutton.h>
#include <qlist.h>
#include <qfile.h>

class KButtonBox:public QWidget
{
  Q_OBJECT

public:
  enum { VERTICAL = 1, HORIZONTAL = 2 };

  KButtonBox(QWidget * parent, int _orientation = HORIZONTAL,
             int border = 0, int _autoborder = 6);

  ~KButtonBox();

  virtual QSize sizeHint() const;

  virtual void resizeEvent(QResizeEvent *);

  QPushButton *addButton(const QString & text, bool noexpand = FALSE);

  void addStretch(int scale = 1);

  void layout();

protected:
  class KButtonBoxItem {
  public:
    QPushButton * button;
    bool noexpand;
    int stretch;
    int actual_size;
  };

  QSize bestButtonSize() const;
  void placeButtons();
  QSize buttonSizeHint(QPushButton *) const;

protected:
  int _border;
  int _autoborder;
  int orientation;
  bool activated;
  QList < KButtonBoxItem > buttons;
};


class KSeparator:public QFrame
{
public:
  KSeparator(QWidget * parent = 0, const char *name = 0, WFlags f = 0);
  KSeparator(int orientation, QWidget * parent = 0, const char *name = 0,
             WFlags f = 0);
  int orientation() const;
  void setOrientation(int);
  virtual QSize sizeHint() const;
};


class KIconLoader
{
public:
  QPixmap loadIcon(const char *);
};

class KGlobal
{
public:
  static KIconLoader *iconLoader();
};


extern void invokeHTMLHelp(QString filename);

#include <qwidget.h>
#include <qdialog.h>

class QPushButton;
class QFrame;

class KCModule:public QWidget
{
  Q_OBJECT

public:
  enum Button { Help = 1, Default = 2, Reset = 4, Cancel = 8,
                Apply = 16, Ok = 32 };
  KCModule(QWidget * parent = 0, const char *name = 0);

  virtual void load() {};
  virtual void save() {};
  virtual void defaults() {};

  static void init();

  int buttons() {
    return _btn;
  };

protected:
  void setButtons(int btn) {
    _btn = btn;
  };

signals:
  void changed(bool state);

private:
  int _btn;

};

#endif

#endif





