/* Copyright 2000 Red Hat, Inc.
 *
 * Than Ngo <than@redhat.de>
 *
 * This software may be freely redistributed under the terms of the GNU
 * public license.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include "passworddialog.h"

PasswordDialog::PasswordDialog(QWidget * parent, const char *name)
	: QDialog(parent, name, TRUE)
{
  setMinimumSize(295, 158);
  setFocusPolicy(StrongFocus);
  setCaption(i18n("Enter login name, password and MSN"));

  static QPixmap logo = KGlobal::iconLoader()->loadIcon("keys");

  QVBoxLayout *top = new QVBoxLayout(this, 8);
  QGridLayout *contents = new QGridLayout(3, 4);
  QHBoxLayout *buttons = new QHBoxLayout();

  top->addSpacing(16);
  top->addStretch(1);
  top->addLayout(contents);
  top->addStretch(1);
  top->addSpacing(16);
  top->addWidget(new KSeparator(QFrame::HLine, this));
  top->addLayout(buttons, 0);
  
  QLabel *label = new QLabel(this);
  label->setPixmap(logo);

  contents->addMultiCellWidget(label, 0, 1, 0, 0);

  label = new QLabel(i18n("&Login name:"), this);
  label->setAlignment(AlignRight);
  loginname = new QLineEdit(this);
  QToolTip::add(loginname,
                i18n("Set the login name to authenticate the user"));
  loginname->setFocus();
  label->setBuddy(loginname);
  contents->addWidget(label, 0, 1);
  contents->addWidget(loginname, 0, 2);

  label = new QLabel(i18n("Pass&word:"), this);
  label->setAlignment(AlignRight);
  password = new QLineEdit(this);
  QToolTip::add(password,
                i18n("Set the password to authenticate the user"));
  password->setEchoMode(QLineEdit::Password);
  label->setBuddy(password);
  contents->addWidget(label, 1, 1);
  contents->addWidget(password, 1, 2);

  label = new QLabel(i18n("&MSN/EAZ:"), this);
  label->setAlignment(AlignRight);
  msn = new QLineEdit(this);
  QToolTip::add(msn, i18n("Set MSN (Euro-ISDN  E-DSS1) or the EAZ\n"
	                  "(German 1TR6 protocol) for ISDN interface name"));
  label->setBuddy(msn);
  contents->addWidget(label, 2, 1);
  contents->addWidget(msn, 2, 2);
  contents->addColSpacing(3, 16);

  QPushButton *ok = new QPushButton(i18n("OK"), this);
  connect(ok, SIGNAL(clicked()), SLOT(accept()));
  buttons->addStretch(1);
  buttons->addWidget(ok);

  QPushButton *cancel = new QPushButton(i18n("Cancel"), this);
  connect(cancel, SIGNAL(clicked()), SLOT(reject()));
  buttons->addWidget(cancel);
}

void PasswordDialog::accept()
{
  QString s("");

  if (msn->text().isEmpty())
    s = i18n("   - MSN/EAZ\n");
  if (password->text().isEmpty())
    s += i18n("   - Password\n");
  if (loginname->text().isEmpty())
    s += i18n("   - Login name\n");
  
  if (s.isEmpty())
    done(Accepted);
  else {
    errormessage(s);
    return;
  }
}

void PasswordDialog::errormessage(QString mytext)
{
  QString s = i18n("The following fields are empty:\n") + mytext + "\n\n";
  s += i18n("Please complete the empty fields.\n\n"
            "Choose 'Cancel' if you don't want to\n"
            "add this provider name to the List.");

  QMessageBox::warning(this, i18n("The fields are empty"), s);
}

QString PasswordDialog::getpassword()
{
  return password->text();
}

QString PasswordDialog::getloginname()
{
  return loginname->text();
}

QString PasswordDialog::getmsn()
{
  return msn->text();
}

void PasswordDialog::fill(QString user, QString pass)
{
  loginname->setText(user);
  password->setText(pass);
}

PasswordDialog::~PasswordDialog()
{
}
